4.23. umbra.components.factory.scriptEditor.workers — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.23. umbra.components.factory.scriptEditor.workers

models.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class Workers.

Others:

## 4.23.1. Module Attributes

`umbra.components.factory.scriptEditor.workers.` `LOGGER`

## 4.23.2. Classes

class `umbra.components.factory.scriptEditor.workers.` `Occurence`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  This class represents a storage object for the `Search_worker` class search occurence.

  Parameters: | **kwargs – line, column, length, text. ( Key / Value pairs )

class `umbra.components.factory.scriptEditor.workers.` `SearchResult`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  This class represents a storage object for the `Search_worker` class search result.

  Parameters: | **kwargs – file, pattern, settings, occurences. ( Key / Value pairs )

class `umbra.components.factory.scriptEditor.workers.` `CacheData`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  This class represents a storage object for the `Search_worker` class cache data.

  Parameters: | **kwargs – content, document. ( Key / Value pairs )

class `umbra.components.factory.scriptEditor.workers.` `Search_worker`(parent, pattern=None, location=None, settings=None)

  Bases: `PyQt4.QtCore.QThread`

  This class is a QThread subclass used to search for a pattern in a directory files.

  Parameters: | parent – Object parent. ( QObject )

  `searchFinished`

    This signal is emited by the `Search_worker` class when the search is finished. ( pyqtSignal )

    Returns: | Search results. ( List )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `pattern`

    This method is the property for self.__pattern attribute.

    Returns: | self.__pattern. ( String )

  `location`

    This method is the property for self.__location attribute.

    Returns: | self.__location. ( Location )

  `settings`

    This method is the property for self.__settings attribute.

    Returns: | self.__settings. ( Location )

  `searchResults`

    This method is the property for self.__searchResults attribute.

    Returns: | self.__searchResults. ( List )

  `run`()

    This method reimplements the `QThread.run()` method.

  `quit`()

    This method reimplements the `QThread.quit()` method.

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »